/*
 * Copyright (c) 2001 World Wide Web Consortium,
 * (Massachusetts Institute of Technology, Institut National de
 * Recherche en Informatique et en Automatique, Keio University). All
 * Rights Reserved. This program is distributed under the W3C's Software
 * Intellectual Property License. This program is distributed in the
 * hope that it will be useful, but WITHOUT ANY WARRANTY; without even
 * the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.
 * See W3C License http://www.w3.org/Consortium/Legal/ for more details.
 */

package org.w3c.dom.contentModel;

/**
 * An element in the context of a <code>CMNode</code>.
 * <p>See also the <a href='http://www.w3.org/TR/2001/WD-DOM-Level-3-CMLS-20010209'>Document Object Model (DOM) Level 3 Content Models and Load
and Save Specification</a>.
 */
public interface CMChildren {
    /**
     * Operator list.
     */
    public String getListOperator();
    public void setListOperator(String listOperator);

    /**
     * Datatype of the element.
     */
    public CMDataType getElementType();
    public void setElementType(CMDataType elementType);

    /**
     * 0 or 1 or many.
     */
    public int getMultiplicity();
    public void setMultiplicity(int multiplicity);

    /**
     * Additional <code>CMNode</code>s in which the element can be defined.
     */
    public CMNamedNodeMap getSubModels();
    public void setSubModels(CMNamedNodeMap subModels);

    /**
     * Boolean defining whether the element type contains child elements and 
     * PCDATA or PCDATA only for mixed element types. True if the element is 
     * of type PCDATA only. Relevant only for mixed content type elements. 
     * Do we really need this attribute ?
     */
    public boolean getIsPCDataOnly();

}
