/*
 * Copyright (c) 2001 World Wide Web Consortium,
 * (Massachusetts Institute of Technology, Institut National de
 * Recherche en Informatique et en Automatique, Keio University). All
 * Rights Reserved. This program is distributed under the W3C's Software
 * Intellectual Property License. This program is distributed in the
 * hope that it will be useful, but WITHOUT ANY WARRANTY; without even
 * the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.
 * See W3C License http://www.w3.org/Consortium/Legal/ for more details.
 */

package org.w3c.dom.contentModel;

/**
 * The primitive datatypes supported currently are: <code>string</code>, 
 * <code>boolean</code>, <code>float</code>, <code>double</code>, 
 * <code>decimal</code>.
 * <p>See also the <a href='http://www.w3.org/TR/2001/WD-DOM-Level-3-CMLS-20010209'>Document Object Model (DOM) Level 3 Content Models and Load
and Save Specification</a>.
 */
public interface CMDataType {
    /**
     * code representing the <code>string</code> data type as defined in XML 
     * Schema Datatypes.
     */
    public static final short STRING_DATATYPE           = 1;
    /**
     * code representing the <code>boolean</code> data type as defined in XML 
     * Schema Datatypes.
     */
    public static final short BOOLEAN_DATATYPE          = 2;
    /**
     * code representing the <code>float</code> data type as defined in XML 
     * Schema Datatypes.
     */
    public static final short FLOAT_DATATYPE            = 3;
    /**
     * code representing the <code>double</code> data type as defined in XML 
     * Schema Datatypes.
     */
    public static final short DOUBLE_DATATYPE           = 4;
    /**
     * code representing a long data type as defined in XML Schema Datatypes.
     */
    public static final short LONG_DATATYPE             = 5;
    /**
     * code representing an <code>integer</code> data type as defined in XML 
     * Schema Datatypes.
     */
    public static final short INT_DATATYPE              = 6;
    /**
     * code representing a short data type as defined in XML Schema Datatypes.
     */
    public static final short SHORT_DATATYPE            = 7;
    /**
     * code representing a byte data type as defined in XML Schema Datatypes.
     */
    public static final short BYTE_DATATYPE             = 8;
    /**
     * The low value for the data type in the value range.
     */
    public int getLowValue();
    public void setLowValue(int lowValue);

    /**
     * The high value for the data type in the value range.
     */
    public int getHighValue();
    public void setHighValue(int highValue);

    /**
     * Returns one of the enumerated code representing the primitive data type.
     * @return code representing the primitive type of the attached data item.
     */
    public short getPrimitiveType();

}
