/*
 * Copyright (c) 2001 World Wide Web Consortium,
 * (Massachusetts Institute of Technology, Institut National de
 * Recherche en Informatique et en Automatique, Keio University). All
 * Rights Reserved. This program is distributed under the W3C's Software
 * Intellectual Property License. This program is distributed in the
 * hope that it will be useful, but WITHOUT ANY WARRANTY; without even
 * the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.
 * See W3C License http://www.w3.org/Consortium/Legal/ for more details.
 */

package org.w3c.dom.contentModel;

/**
 * <code>CMNode</code>is analogous to a <code>Node</code> in the Core DOM, 
 * e.g., an element declaration. This can exist for both 
 * <code>CMExternalModel</code> (include/ignore must be handled here) and 
 * <code>CMModel</code>. It should handle the following: 
 * <p> 
 * <code> interface CommentsPIsDeclaration { attribute ProcessingInstruction pis; attribute Comment comments; }; interface Conditional Declaration { attribute boolean includeIgnore; };</code>
 *  
 * <p>Opaque. 
 * <p>See also the <a href='http://www.w3.org/TR/2001/WD-DOM-Level-3-CMLS-20010209'>Document Object Model (DOM) Level 3 Content Models and Load
and Save Specification</a>.
 */
public interface CMNode {
    /**
     * The node is an <code>ElementDeclaration</code>.
     */
    public static final short ELEMENT_DECLARATION       = 1;
    /**
     * The node is an <code>AttributeDeclaration</code>.
     */
    public static final short ATTRIBUTE_DECLARATION     = 2;
    /**
     * The node is a <code>CMNotationDeclaration</code>.
     */
    public static final short CM_NOTATION_DECLARATION   = 3;
    /**
     * The node is an <code>EntityDeclaration</code>.
     */
    public static final short ENTITY_DECLARATION        = 4;
    /**
     * The node is a <code>CMChildren</code>.
     */
    public static final short CM_CHILDREN               = 5;
    /**
     * The node is a <code>CMModel</code>.
     */
    public static final short CM_MODEL                  = 6;
    /**
     * The node is a <code>CMExternalModel</code>.
     */
    public static final short CM_EXTERNALMODEL          = 7;
    /**
     * A code representing the underlying object as defined above.
     */
    public short getCmNodeType();

    /**
     * Creates a copy of <code>CMModel</code>. No document refers to the 
     * <code>CMNode</code> returned.
     * @return Cloned <code>CMNode</code>.
     */
    public CMNode cloneCM();

    /**
     * Creates a copy of <code>CMExternalModel</code>. It is possible that a 
     * document would not refer to the <code>CMNode</code> returned.
     * @return Cloned <code>CMNode</code>.
     */
    public CMNode cloneExternalCM();

}
