/*
 * Copyright (c) 2001 World Wide Web Consortium,
 * (Massachusetts Institute of Technology, Institut National de
 * Recherche en Informatique et en Automatique, Keio University). All
 * Rights Reserved. This program is distributed under the W3C's Software
 * Intellectual Property License. This program is distributed in the
 * hope that it will be useful, but WITHOUT ANY WARRANTY; without even
 * the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.
 * See W3C License http://www.w3.org/Consortium/Legal/ for more details.
 */

package org.w3c.dom.contentModel;

import org.w3c.dom.Node;
import org.w3c.dom.DOMException;
import org.w3c.dom.Element;

/**
 * This interface extends the <code>Element</code> interface with additional 
 * methods for guided document editing.
 * <p>See also the <a href='http://www.w3.org/TR/2001/WD-DOM-Level-3-CMLS-20010209'>Document Object Model (DOM) Level 3 Content Models and Load
and Save Specification</a>.
 */
public interface ElementCM extends Element {
    /**
     * Determines element content type.
     * @return Constant for mixed, empty, any, etc.
     */
    public int contentType();

    /**
     * gets the CM editing object describing this element
     * @return ElementDeclaration object
     * @exception DOMException
     *   If no DTD is present raises this exception
     */
    public ElementDeclaration getElementDeclaration()
                                                    throws DOMException;

    /**
     * Sets value for specified attribute.
     * @param attrname Name of attribute.
     * @param attrval Value to be assigned to the attribute.
     * @return Success or failure.
     */
    public boolean canSetAttribute(String attrname, 
                                   String attrval);

    /**
     * Determines if attribute can be set.
     * @param node <code>Node</code> in which the attribute can possibly be 
     *   set.
     * @return Success or failure.
     */
    public boolean canSetAttributeNode(Node node);

    /**
     * Determines if namespace of attribute's node can be set.
     * @param node Attribute's <code>Node</code> in which to set the 
     *   namespace.
     * @param namespaceURI <code>namespaceURI</code> of namespace.
     * @param localName <code>localName</code> of namespace.
     * @return Success or failure.
     */
    public boolean canSetAttributeNodeNS(Node node, 
                                         String namespaceURI, 
                                         String localName);

    /**
     * Determines if namespace of attribute can be set.
     * @param attrname Name of attribute.
     * @param attrval Value to be assigned to the attribute.
     * @param namespaceURI <code>namespaceURI</code> of namespace.
     * @param localName <code>localName</code> of namespace.
     * @return Success or failure.
     */
    public boolean canSetAttributeNS(String attrname, 
                                     String attrval, 
                                     String namespaceURI, 
                                     String localName);

}
